:orphan:

Citing Matplotlib
=================

If Matplotlib contributes to a project that leads to a scientific
publication, please acknowledge this fact by citing `Hunter et al (2007)
<http://doi.org/10.1109/MCSE.2007.55>`_ using this ready-made BibTeX entry:

.. code-block:: bibtex

   @Article{Hunter:2007,
     Author    = {Hunter, J. D.},
     Title     = {Matplotlib: A 2D graphics environment},
     Journal   = {Computing In Science \& Engineering},
     Volume    = {9},
     Number    = {3},
     Pages     = {90--95},
     abstract  = {Matplotlib is a 2D graphics package used for Python
     for application development, interactive scripting, and
     publication-quality image generation across user
     interfaces and operating systems.},
     publisher = {IEEE COMPUTER SOC},
     doi       = {10.1109/MCSE.2007.55},
     year      = 2007
   }

DOIs
----
v2.2.2
   .. image:: https://zenodo.org/badge/DOI/10.5281/zenodo.1202077.svg
      :target: https://doi.org/10.5281/zenodo.1202077
v2.2.1
   .. image:: https://zenodo.org/badge/DOI/10.5281/zenodo.1202050.svg
      :target: https://doi.org/10.5281/zenodo.1202050
v2.2.0
   .. image:: https://zenodo.org/badge/DOI/10.5281/zenodo.1189358.svg
      :target: https://doi.org/10.5281/zenodo.1189358
v2.1.2
   .. image:: https://zenodo.org/badge/DOI/10.5281/zenodo.1154287.svg
      :target: https://doi.org/10.5281/zenodo.1154287
v2.1.1
   .. image:: https://zenodo.org/badge/DOI/10.5281/zenodo.1098480.svg
      :target: https://doi.org/10.5281/zenodo.1098480
v2.1.0
   .. image:: https://zenodo.org/badge/doi/10.5281/zenodo.1004650.svg
      :target: https://doi.org/10.5281/zenodo.1004650
v2.0.2
   .. image:: https://zenodo.org/badge/doi/10.5281/zenodo.573577.svg
      :target: https://doi.org/10.5281/zenodo.573577
v2.0.1
   .. image:: https://zenodo.org/badge/doi/10.5281/zenodo.570311.svg
      :target: https://doi.org/10.5281/zenodo.570311
v2.0.0
   .. image:: https://zenodo.org/badge/doi/10.5281/zenodo.248351.svg
      :target: https://doi.org/10.5281/zenodo.248351
v1.5.3
   .. image:: https://zenodo.org/badge/doi/10.5281/zenodo.61948.svg
      :target: https://doi.org/10.5281/zenodo.61948
v1.5.2
   .. image:: https://zenodo.org/badge/doi/10.5281/zenodo.56926.svg
      :target: https://doi.org/10.5281/zenodo.56926
v1.5.1
   .. image:: https://zenodo.org/badge/doi/10.5281/zenodo.44579.svg
      :target: https://doi.org/10.5281/zenodo.44579
v1.5.0
   .. image:: https://zenodo.org/badge/doi/10.5281/zenodo.32914.svg
      :target: https://doi.org/10.5281/zenodo.32914
v1.4.3
   .. image:: https://zenodo.org/badge/doi/10.5281/zenodo.15423.svg
      :target: https://doi.org/10.5281/zenodo.15423
v1.4.2
   .. image:: https://zenodo.org/badge/doi/10.5281/zenodo.12400.svg
      :target: https://doi.org/10.5281/zenodo.12400
v1.4.1
   .. image:: https://zenodo.org/badge/doi/10.5281/zenodo.12287.svg
      :target: https://doi.org/10.5281/zenodo.12287
v1.4.0
   .. image:: https://zenodo.org/badge/doi/10.5281/zenodo.11451.svg
      :target: https://doi.org/10.5281/zenodo.11451
